@@ -6,18 +6,17 @@
 */
 
 #include "kstatusnotifieritem.h"
-#include "kstatusnotifieritemprivate_p.h"
-#include "debug_p.h"
 #include "config-knotifications.h"
+#include "debug_p.h"
+#include "kstatusnotifieritemprivate_p.h"
 
-
-#include <QMessageBox>
-#include <QPixmap>
-#include <QImage>
 #include <QApplication>
+#include <QImage>
 #include <QMenu>
+#include <QMessageBox>
 #include <QMovie>
 #include <QPainter>
+#include <QPixmap>
 #include <QStandardPaths>
 #ifdef Q_OS_MACOS
 #include <QFontDatabase>
@@ -31,11 +30,11 @@
 
 #if HAVE_DBUSMENUQT
 #include <dbusmenuexporter.h>
-#endif //HAVE_DBUSMENUQT
+#endif // HAVE_DBUSMENUQT
 #endif
 
-#include <QTimer>
 #include <KWindowInfo>
+#include <QTimer>
 #include <kwindowsystem.h>
 
 #include <cstdlib>
@@ -44,15 +43,15 @@ static const char s_statusNotifierWatcherServiceName[] = "org.kde.StatusNotifier
 static const int s_legacyTrayIconSize = 24;
 
 KStatusNotifierItem::KStatusNotifierItem(QObject *parent)
-    : QObject(parent),
-      d(new KStatusNotifierItemPrivate(this))
+    : QObject(parent)
+    , d(new KStatusNotifierItemPrivate(this))
 {
     d->init(QString());
 }
 
 KStatusNotifierItem::KStatusNotifierItem(const QString &id, QObject *parent)
-    : QObject(parent),
-      d(new KStatusNotifierItemPrivate(this))
+    : QObject(parent)
+    , d(new KStatusNotifierItemPrivate(this))
 {
     d->init(id);
 }
@@ -75,7 +74,7 @@ KStatusNotifierItem::~KStatusNotifierItem()
 
 QString KStatusNotifierItem::id() const
 {
-    //qCDebug(LOG_KNOTIFICATIONS) << "id requested" << d->id;
+    // qCDebug(LOG_KNOTIFICATIONS) << "id requested" << d->id;
     return d->id;
 }
 
@@ -108,14 +107,15 @@ void KStatusNotifierItem::setStatus(const ItemStatus status)
     d->status = status;
 
 #ifdef QT_DBUS_LIB
-    emit d->statusNotifierItemDBus->NewStatus(QString::fromLatin1(metaObject()->enumerator(metaObject()->indexOfEnumerator("ItemStatus")).valueToKey(d->status)));
+    Q_EMIT d->statusNotifierItemDBus->NewStatus(
+        QString::fromLatin1(metaObject()->enumerator(metaObject()->indexOfEnumerator("ItemStatus")).valueToKey(d->status)));
 #endif
     if (d->systemTrayIcon) {
         d->syncLegacySystemTrayIcon();
     }
 }
 
-//normal icon
+// normal icon
 
 void KStatusNotifierItem::setIconByName(const QString &name)
 {
@@ -123,12 +123,11 @@ void KStatusNotifierItem::setIconByName(const QString &name)
         return;
     }
 
-
     d->iconName = name;
 
 #ifdef QT_DBUS_LIB
     d->serializedIcon = KDbusImageVector();
-    emit d->statusNotifierItemDBus->NewIcon();
+    Q_EMIT d->statusNotifierItemDBus->NewIcon();
 #endif
 
     if (d->systemTrayIcon) {
@@ -151,7 +150,7 @@ void KStatusNotifierItem::setIconByPixmap(const QIcon &icon)
 
 #ifdef QT_DBUS_LIB
     d->serializedIcon = d->iconToVector(icon);
-    emit d->statusNotifierItemDBus->NewIcon();
+    Q_EMIT d->statusNotifierItemDBus->NewIcon();
 #endif
 
     d->icon = icon;
@@ -173,7 +172,7 @@ void KStatusNotifierItem::setOverlayIconByName(const QString &name)
 
     d->overlayIconName = name;
 #ifdef QT_DBUS_LIB
-    emit d->statusNotifierItemDBus->NewOverlayIcon();
+    Q_EMIT d->statusNotifierItemDBus->NewOverlayIcon();
 #endif
     if (d->systemTrayIcon) {
         QPixmap iconPixmap = QIcon::fromTheme(d->iconName).pixmap(s_legacyTrayIconSize, s_legacyTrayIconSize);
@@ -202,7 +201,7 @@ void KStatusNotifierItem::setOverlayIconByPixmap(const QIcon &icon)
 
 #ifdef QT_DBUS_LIB
     d->serializedOverlayIcon = d->iconToVector(icon);
-    emit d->statusNotifierItemDBus->NewOverlayIcon();
+    Q_EMIT d->statusNotifierItemDBus->NewOverlayIcon();
 #endif
 
     d->overlayIcon = icon;
@@ -222,7 +221,7 @@ QIcon KStatusNotifierItem::overlayIconPixmap() const
     return d->overlayIcon;
 }
 
-//Icons and movie for requesting attention state
+// Icons and movie for requesting attention state
 
 void KStatusNotifierItem::setAttentionIconByName(const QString &name)
 {
@@ -234,7 +233,7 @@ void KStatusNotifierItem::setAttentionIconByName(const QString &name)
 
 #ifdef QT_DBUS_LIB
     d->serializedAttentionIcon = KDbusImageVector();
-    emit d->statusNotifierItemDBus->NewAttentionIcon();
+    Q_EMIT d->statusNotifierItemDBus->NewAttentionIcon();
 #endif
 }
 
@@ -254,7 +253,7 @@ void KStatusNotifierItem::setAttentionIconByPixmap(const QIcon &icon)
 
 #ifdef QT_DBUS_LIB
     d->serializedAttentionIcon = d->iconToVector(icon);
-    emit d->statusNotifierItemDBus->NewAttentionIcon();
+    Q_EMIT d->statusNotifierItemDBus->NewAttentionIcon();
 #endif
 }
 
@@ -275,7 +274,7 @@ void KStatusNotifierItem::setAttentionMovieByName(const QString &name)
     d->movie = nullptr;
 
 #ifdef QT_DBUS_LIB
-    emit d->statusNotifierItemDBus->NewAttentionIcon();
+    Q_EMIT d->statusNotifierItemDBus->NewAttentionIcon();
 #endif
 
     if (d->systemTrayIcon) {
@@ -289,27 +288,26 @@ QString KStatusNotifierItem::attentionMovieName() const
     return d->movieName;
 }
 
-//ToolTip
+// ToolTip
 
 #ifdef Q_OS_MACOS
 static void setTrayToolTip(KStatusNotifierLegacyIcon *systemTrayIcon, const QString &title, const QString &subTitle)
 {
     if (systemTrayIcon) {
-        bool tEmpty = title.isEmpty(),
-                    stEmpty = subTitle.isEmpty();
-                    if (tEmpty) {
-                        if (!stEmpty) {
-                            systemTrayIcon->setToolTip(subTitle);
-                        } else {
-                            systemTrayIcon->setToolTip(title);
-                        }
-                    } else {
-                        if (stEmpty) {
-                            systemTrayIcon->setToolTip(title);
-                        } else {
-                            systemTrayIcon->setToolTip(title + QStringLiteral("\n") + subTitle);
-                        }
-                    }
+        bool tEmpty = title.isEmpty(), stEmpty = subTitle.isEmpty();
+        if (tEmpty) {
+            if (!stEmpty) {
+                systemTrayIcon->setToolTip(subTitle);
+            } else {
+                systemTrayIcon->setToolTip(title);
+            }
+        } else {
+            if (stEmpty) {
+                systemTrayIcon->setToolTip(title);
+            } else {
+                systemTrayIcon->setToolTip(title + QStringLiteral("\n") + subTitle);
+            }
+        }
     }
 }
 #else
@@ -323,32 +321,27 @@ static void setTrayToolTip(KStatusNotifierLegacyIcon *systemTrayIcon, const QStr
 
 void KStatusNotifierItem::setToolTip(const QString &iconName, const QString &title, const QString &subTitle)
 {
-    if (d->toolTipIconName == iconName &&
-            d->toolTipTitle == title &&
-            d->toolTipSubTitle == subTitle) {
+    if (d->toolTipIconName == iconName && d->toolTipTitle == title && d->toolTipSubTitle == subTitle) {
         return;
     }
 
     d->toolTipIconName = iconName;
 
     d->toolTipTitle = title;
-//     if (d->systemTrayIcon) {
-//         d->systemTrayIcon->setToolTip(title);
-//     }
     setTrayToolTip(d->systemTrayIcon, title, subTitle);
     d->toolTipSubTitle = subTitle;
 
 #ifdef QT_DBUS_LIB
     d->serializedToolTipIcon = KDbusImageVector();
-    emit d->statusNotifierItemDBus->NewToolTip();
+    Q_EMIT d->statusNotifierItemDBus->NewToolTip();
 #endif
 }
 
 void KStatusNotifierItem::setToolTip(const QIcon &icon, const QString &title, const QString &subTitle)
 {
-    if (d->toolTipIconName.isEmpty() && d->toolTipIcon.cacheKey() == icon.cacheKey() &&
-            d->toolTipTitle == title &&
-            d->toolTipSubTitle == subTitle) {
+    if (d->toolTipIconName.isEmpty() && d->toolTipIcon.cacheKey() == icon.cacheKey() //
+        && d->toolTipTitle == title //
+        && d->toolTipSubTitle == subTitle) {
         return;
     }
 
@@ -356,15 +349,12 @@ void KStatusNotifierItem::setToolTip(const QIcon &icon, const QString &title, co
     d->toolTipIcon = icon;
 
     d->toolTipTitle = title;
-//     if (d->systemTrayIcon) {
-//         d->systemTrayIcon->setToolTip(title);
-//     }
     setTrayToolTip(d->systemTrayIcon, title, subTitle);
 
     d->toolTipSubTitle = subTitle;
 #ifdef QT_DBUS_LIB
     d->serializedToolTipIcon = d->iconToVector(icon);
-    emit d->statusNotifierItemDBus->NewToolTip();
+    Q_EMIT d->statusNotifierItemDBus->NewToolTip();
 #endif
 }
 
@@ -377,7 +367,7 @@ void KStatusNotifierItem::setToolTipIconByName(const QString &name)
     d->toolTipIconName = name;
 #ifdef QT_DBUS_LIB
     d->serializedToolTipIcon = KDbusImageVector();
-    emit d->statusNotifierItemDBus->NewToolTip();
+    Q_EMIT d->statusNotifierItemDBus->NewToolTip();
 #endif
 }
 
@@ -397,7 +387,7 @@ void KStatusNotifierItem::setToolTipIconByPixmap(const QIcon &icon)
 
 #ifdef QT_DBUS_LIB
     d->serializedToolTipIcon = d->iconToVector(icon);
-    emit d->statusNotifierItemDBus->NewToolTip();
+    Q_EMIT d->statusNotifierItemDBus->NewToolTip();
 #endif
 }
 
@@ -415,11 +405,8 @@ void KStatusNotifierItem::setToolTipTitle(const QString &title)
     d->toolTipTitle = title;
 
 #ifdef QT_DBUS_LIB
-    emit d->statusNotifierItemDBus->NewToolTip();
+    Q_EMIT d->statusNotifierItemDBus->NewToolTip();
 #endif
-//     if (d->systemTrayIcon) {
-//         d->systemTrayIcon->setToolTip(title);
-//     }
     setTrayToolTip(d->systemTrayIcon, title, d->toolTipSubTitle);
 }
 
@@ -436,7 +423,7 @@ void KStatusNotifierItem::setToolTipSubTitle(const QString &subTitle)
 
     d->toolTipSubTitle = subTitle;
 #ifdef QT_DBUS_LIB
-    emit d->statusNotifierItemDBus->NewToolTip();
+    Q_EMIT d->statusNotifierItemDBus->NewToolTip();
 #else
     setTrayToolTip(d->systemTrayIcon, d->toolTipTitle, subTitle);
 #endif
@@ -473,6 +460,7 @@ void KStatusNotifierItem::setContextMenu(QMenu *menu)
             d->menuObjectPath = QStringLiteral("/MenuBar");
 #if HAVE_DBUSMENUQT
             new DBusMenuExporter(d->menuObjectPath, menu, d->statusNotifierItemDBus->dbusConnection());
+            Q_EMIT d->statusNotifierItemDBus->NewMenu();
 #endif
         }
 
@@ -496,21 +484,17 @@ void KStatusNotifierItem::setAssociatedWidget(QWidget *associatedWidget)
         d->associatedWidget = associatedWidget->window();
         d->associatedWidgetPos = QPoint(-1, -1);
 
-        QObject::connect(KWindowSystem::self(), &KWindowSystem::windowAdded,
-            d->associatedWidget, [this](WId id) {
-                if(d->associatedWidget->winId() == id && d->associatedWidgetPos != QPoint(-1, -1)) {
-                    d->associatedWidget->move(d->associatedWidgetPos);
-                }
+        QObject::connect(KWindowSystem::self(), &KWindowSystem::windowAdded, d->associatedWidget, [this](WId id) {
+            if (d->associatedWidget->winId() == id && d->associatedWidgetPos != QPoint(-1, -1)) {
+                d->associatedWidget->move(d->associatedWidgetPos);
             }
-        );
+        });
 
-        QObject::connect(KWindowSystem::self(), &KWindowSystem::windowRemoved,
-            d->associatedWidget, [this](WId id) {
-                if(d->associatedWidget->winId() == id) {
-                    d->associatedWidgetPos = d->associatedWidget->pos();
-                }
+        QObject::connect(KWindowSystem::self(), &KWindowSystem::windowRemoved, d->associatedWidget, [this](WId id) {
+            if (d->associatedWidget->winId() == id) {
+                d->associatedWidgetPos = d->associatedWidget->pos();
             }
-        );
+        });
     } else if (d->associatedWidget) {
         KWindowSystem::self()->disconnect(d->associatedWidget);
         d->associatedWidget = nullptr;
@@ -566,7 +550,7 @@ void KStatusNotifierItem::removeAction(const QString &name)
     d->actionCollection.remove(name);
 }
 
-QAction* KStatusNotifierItem::action(const QString &name) const
+QAction *KStatusNotifierItem::action(const QString &name) const
 {
     return d->actionCollection.value(name);
 }
@@ -603,7 +587,8 @@ void KStatusNotifierItem::showMessage(const QString &title, const QString &messa
 {
 #ifdef QT_DBUS_LIB
     if (!d->notificationsClient) {
-        d->notificationsClient = new org::freedesktop::Notifications(QStringLiteral("org.freedesktop.Notifications"), QStringLiteral("/org/freedesktop/Notifications"),
+        d->notificationsClient = new org::freedesktop::Notifications(QStringLiteral("org.freedesktop.Notifications"),
+                                                                     QStringLiteral("/org/freedesktop/Notifications"),
                                                                      QDBusConnection::sessionBus());
     }
 
@@ -636,15 +621,16 @@ QString KStatusNotifierItem::title() const
 
 void KStatusNotifierItem::activate(const QPoint &pos)
 {
-    //if the user activated the icon the NeedsAttention state is no longer necessary
-    //FIXME: always true?
+    // if the user activated the icon the NeedsAttention state is no longer necessary
+    // FIXME: always true?
     if (d->status == NeedsAttention) {
         d->status = Active;
 #ifdef Q_OS_MACOS
         QtMac::setBadgeLabelText(QString());
 #endif
 #ifdef QT_DBUS_LIB
-        emit d->statusNotifierItemDBus->NewStatus(QString::fromLatin1(metaObject()->enumerator(metaObject()->indexOfEnumerator("ItemStatus")).valueToKey(d->status)));
+        Q_EMIT d->statusNotifierItemDBus->NewStatus(
+            QString::fromLatin1(metaObject()->enumerator(metaObject()->indexOfEnumerator("ItemStatus")).valueToKey(d->status)));
 #endif
     }
 
@@ -660,13 +646,18 @@ void KStatusNotifierItem::activate(const QPoint &pos)
     }
 
     if (!d->associatedWidget) {
-        emit activateRequested(true, pos);
+        Q_EMIT activateRequested(true, pos);
         return;
     }
 
     d->checkVisibility(pos);
 }
 
+QString KStatusNotifierItem::providedToken() const
+{
+    return d->statusNotifierItemDBus->m_xdgActivationToken;
+}
+
 bool KStatusNotifierItemPrivate::checkVisibility(QPoint pos, bool perform)
 {
 #ifdef Q_OS_WIN
@@ -677,31 +668,31 @@ bool KStatusNotifierItemPrivate::checkVisibility(QPoint pos, bool perform)
     if (GetTickCount() - dwTickCount < 300) {
         // we were active in the last 300ms -> hide it
         minimizeRestore(false);
-        emit activateRequested(false, pos);
+        Q_EMIT activateRequested(false, pos);
     } else {
         minimizeRestore(true);
-        emit activateRequested(true, pos);
+        Q_EMIT activateRequested(true, pos);
     }
 #endif
 #else
     // mapped = visible (but possibly obscured)
     const bool mapped = associatedWidget->isVisible() && !associatedWidget->isMinimized();
 
-//    - not mapped -> show, raise, focus
-//    - mapped
-//        - obscured -> raise, focus
-//        - not obscured -> hide
-    //info1.mappingState() != NET::Visible -> window on another desktop?
+    //    - not mapped -> show, raise, focus
+    //    - mapped
+    //        - obscured -> raise, focus
+    //        - not obscured -> hide
+    // info1.mappingState() != NET::Visible -> window on another desktop?
     if (!mapped) {
         if (perform) {
             minimizeRestore(true);
-            emit q->activateRequested(true, pos);
+            Q_EMIT q->activateRequested(true, pos);
         }
 
         return true;
     } else if (QGuiApplication::platformName() == QLatin1String("xcb")) {
         const KWindowInfo info1(associatedWidget->winId(), NET::XAWMState | NET::WMState | NET::WMDesktop);
-        QListIterator< WId > it(KWindowSystem::stackingOrder());
+        QListIterator<WId> it(KWindowSystem::stackingOrder());
         it.toBack();
         while (it.hasPrevious()) {
             WId id = it.previous();
@@ -723,9 +714,19 @@ bool KStatusNotifierItemPrivate::checkVisibility(QPoint pos, bool perform)
                 continue; // obscured by window kept above -> ignore
             }
 
-            NET::WindowType type = info2.windowType(NET::NormalMask | NET::DesktopMask
-                                                    | NET::DockMask | NET::ToolbarMask | NET::MenuMask | NET::DialogMask
-                                                    | NET::OverrideMask | NET::TopMenuMask | NET::UtilityMask | NET::SplashMask);
+            /* clang-format off */
+            static constexpr auto flags = (NET::NormalMask
+                                           | NET::DesktopMask
+                                           | NET::DockMask
+                                           | NET::ToolbarMask
+                                           | NET::MenuMask
+                                           | NET::DialogMask
+                                           | NET::OverrideMask
+                                           | NET::TopMenuMask
+                                           | NET::UtilityMask
+                                           | NET::SplashMask);
+            /* clang-format on */
+            NET::WindowType type = info2.windowType(flags);
 
             if (type == NET::Dock || type == NET::TopMenu) {
                 continue; // obscured by dock or topmenu -> ignore
@@ -734,17 +735,17 @@ bool KStatusNotifierItemPrivate::checkVisibility(QPoint pos, bool perform)
             if (perform) {
                 KWindowSystem::raiseWindow(associatedWidget->winId());
                 KWindowSystem::forceActiveWindow(associatedWidget->winId());
-                emit q->activateRequested(true, pos);
+                Q_EMIT q->activateRequested(true, pos);
             }
 
             return true;
         }
 
-        //not on current desktop?
+        // not on current desktop?
         if (!info1.isOnCurrentDesktop()) {
             if (perform) {
                 KWindowSystem::activateWindow(associatedWidget->winId());
-                emit q->activateRequested(true, pos);
+                Q_EMIT q->activateRequested(true, pos);
             }
 
             return true;
@@ -752,14 +753,14 @@ bool KStatusNotifierItemPrivate::checkVisibility(QPoint pos, bool perform)
 
         if (perform) {
             minimizeRestore(false); // hide
-            emit q->activateRequested(false, pos);
+            Q_EMIT q->activateRequested(false, pos);
         }
 
         return false;
     } else {
         if (perform) {
             minimizeRestore(false); // hide
-            emit q->activateRequested(false, pos);
+            Q_EMIT q->activateRequested(false, pos);
         }
         return false;
     }
@@ -771,32 +772,35 @@ bool KStatusNotifierItemPrivate::checkVisibility(QPoint pos, bool perform)
 bool KStatusNotifierItem::eventFilter(QObject *watched, QEvent *event)
 {
     if (d->systemTrayIcon == nullptr) {
-        //FIXME: ugly ugly workaround to weird QMenu's focus problems
-        if (watched == d->menu &&
-                (event->type() == QEvent::WindowDeactivate || (event->type() == QEvent::MouseButtonRelease && static_cast<QMouseEvent *>(event)->button() == Qt::LeftButton))) {
-            //put at the back of even queue to let the action activate anyways
-            QTimer::singleShot(0, this, [this]() { d->hideMenu(); });
+        // FIXME: ugly ugly workaround to weird QMenu's focus problems
+        if (watched == d->menu
+            && (event->type() == QEvent::WindowDeactivate
+                || (event->type() == QEvent::MouseButtonRelease && static_cast<QMouseEvent *>(event)->button() == Qt::LeftButton))) {
+            // put at the back of even queue to let the action activate anyways
+            QTimer::singleShot(0, this, [this]() {
+                d->hideMenu();
+            });
         }
     }
     return false;
 }
 
-//KStatusNotifierItemPrivate
+// KStatusNotifierItemPrivate
 
 const int KStatusNotifierItemPrivate::s_protocolVersion = 0;
 
 KStatusNotifierItemPrivate::KStatusNotifierItemPrivate(KStatusNotifierItem *item)
-    : q(item),
-      category(KStatusNotifierItem::ApplicationStatus),
-      status(KStatusNotifierItem::Passive),
-      movie(nullptr),
-      systemTrayIcon(nullptr),
-      menu(nullptr),
-      associatedWidget(nullptr),
-      titleAction(nullptr),
-      hasQuit(false),
-      onAllDesktops(false),
-      standardActionsEnabled(true)
+    : q(item)
+    , category(KStatusNotifierItem::ApplicationStatus)
+    , status(KStatusNotifierItem::Passive)
+    , movie(nullptr)
+    , systemTrayIcon(nullptr)
+    , menu(nullptr)
+    , associatedWidget(nullptr)
+    , titleAction(nullptr)
+    , hasQuit(false)
+    , onAllDesktops(false)
+    , standardActionsEnabled(true)
 {
 }
 
@@ -811,14 +815,13 @@ void KStatusNotifierItemPrivate::init(const QString &extraId)
     statusNotifierItemDBus = new KStatusNotifierItemDBus(q);
 
     QDBusServiceWatcher *watcher = new QDBusServiceWatcher(QString::fromLatin1(s_statusNotifierWatcherServiceName),
-            QDBusConnection::sessionBus(),
-            QDBusServiceWatcher::WatchForOwnerChange,
-            q);
-    QObject::connect(watcher, SIGNAL(serviceOwnerChanged(QString,QString,QString)),
-                     q, SLOT(serviceChange(QString,QString,QString)));
+                                                           QDBusConnection::sessionBus(),
+                                                           QDBusServiceWatcher::WatchForOwnerChange,
+                                                           q);
+    QObject::connect(watcher, SIGNAL(serviceOwnerChanged(QString, QString, QString)), q, SLOT(serviceChange(QString, QString, QString)));
 #endif
 
-    //create a default menu, just like in KSystemtrayIcon
+    // create a default menu, just like in KSystemtrayIcon
     QMenu *m = new QMenu(associatedWidget);
 
     title = QGuiApplication::applicationDisplayName();
@@ -872,8 +875,9 @@ void KStatusNotifierItemPrivate::registerToDaemon()
 #ifdef QT_DBUS_LIB
     qCDebug(LOG_KNOTIFICATIONS) << "Registering a client interface to the KStatusNotifierWatcher";
     if (!statusNotifierWatcher) {
-        statusNotifierWatcher = new org::kde::StatusNotifierWatcher(QString::fromLatin1(s_statusNotifierWatcherServiceName), QStringLiteral("/StatusNotifierWatcher"),
-                QDBusConnection::sessionBus());
+        statusNotifierWatcher = new org::kde::StatusNotifierWatcher(QString::fromLatin1(s_statusNotifierWatcherServiceName),
+                                                                    QStringLiteral("/StatusNotifierWatcher"),
+                                                                    QDBusConnection::sessionBus());
     }
 
     if (statusNotifierWatcher->isValid()) {
@@ -885,26 +889,24 @@ void KStatusNotifierItemPrivate::registerToDaemon()
         msg.setArguments(QVariantList{QStringLiteral("org.kde.StatusNotifierWatcher"), QStringLiteral("ProtocolVersion")});
         QDBusPendingCall async = QDBusConnection::sessionBus().asyncCall(msg);
         QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(async, q);
-        QObject::connect(watcher, &QDBusPendingCallWatcher::finished, q,
-            [this, watcher] {
-                watcher->deleteLater();
-                QDBusPendingReply<QVariant> reply = *watcher;
-                if (reply.isError()) {
-                    qCDebug(LOG_KNOTIFICATIONS) << "Failed to read protocol version of KStatusNotifierWatcher";
-                    setLegacySystemTrayEnabled(true);
+        QObject::connect(watcher, &QDBusPendingCallWatcher::finished, q, [this, watcher] {
+            watcher->deleteLater();
+            QDBusPendingReply<QVariant> reply = *watcher;
+            if (reply.isError()) {
+                qCDebug(LOG_KNOTIFICATIONS) << "Failed to read protocol version of KStatusNotifierWatcher";
+                setLegacySystemTrayEnabled(true);
+            } else {
+                bool ok = false;
+                const int protocolVersion = reply.value().toInt(&ok);
+                if (ok && protocolVersion == s_protocolVersion) {
+                    statusNotifierWatcher->RegisterStatusNotifierItem(statusNotifierItemDBus->service());
+                    setLegacySystemTrayEnabled(false);
                 } else {
-                    bool ok = false;
-                    const int protocolVersion = reply.value().toInt(&ok);
-                    if (ok && protocolVersion == s_protocolVersion) {
-                        statusNotifierWatcher->RegisterStatusNotifierItem(statusNotifierItemDBus->service());
-                        setLegacySystemTrayEnabled(false);
-                    } else {
-                        qCDebug(LOG_KNOTIFICATIONS) << "KStatusNotifierWatcher has incorrect protocol version";
-                        setLegacySystemTrayEnabled(true);
-                    }
+                    qCDebug(LOG_KNOTIFICATIONS) << "KStatusNotifierWatcher has incorrect protocol version";
+                    setLegacySystemTrayEnabled(true);
                 }
             }
-        );
+        });
     } else {
         qCDebug(LOG_KNOTIFICATIONS) << "KStatusNotifierWatcher not reachable";
         useLegacy = true;
@@ -919,7 +921,7 @@ void KStatusNotifierItemPrivate::serviceChange(const QString &name, const QStrin
 {
     Q_UNUSED(name)
     if (newOwner.isEmpty()) {
-        //unregistered
+        // unregistered
         qCDebug(LOG_KNOTIFICATIONS) << "Connection to the KStatusNotifierWatcher lost";
         setLegacyMode(true);
 #ifdef QT_DBUS_LIB
@@ -927,7 +929,7 @@ void KStatusNotifierItemPrivate::serviceChange(const QString &name, const QStrin
         statusNotifierWatcher = nullptr;
 #endif
     } else if (oldOwner.isEmpty()) {
-        //registered
+        // registered
         setLegacyMode(false);
     }
 }
@@ -935,10 +937,10 @@ void KStatusNotifierItemPrivate::serviceChange(const QString &name, const QStrin
 void KStatusNotifierItemPrivate::setLegacyMode(bool legacy)
 {
     if (legacy) {
-        //unregistered
+        // unregistered
         setLegacySystemTrayEnabled(true);
     } else {
-        //registered
+        // registered
         registerToDaemon();
     }
 }
@@ -953,7 +955,7 @@ void KStatusNotifierItemPrivate::legacyWheelEvent(int delta)
 void KStatusNotifierItemPrivate::legacyActivated(QSystemTrayIcon::ActivationReason reason)
 {
     if (reason == QSystemTrayIcon::MiddleClick) {
-        emit q->secondaryActivateRequested(systemTrayIcon->geometry().topLeft());
+        Q_EMIT q->secondaryActivateRequested(systemTrayIcon->geometry().topLeft());
     } else if (reason == QSystemTrayIcon::Trigger) {
         q->activate(systemTrayIcon->geometry().topLeft());
     }
@@ -1009,7 +1011,7 @@ void KStatusNotifierItemPrivate::syncLegacySystemTrayIcon()
 {
     if (status == KStatusNotifierItem::NeedsAttention) {
 #ifdef Q_OS_MACOS
-        QtMac::setBadgeLabelText(QString(QChar(0x26a0))/*QStringLiteral("!")*/);
+        QtMac::setBadgeLabelText(QString(QChar(0x26a0)) /*QStringLiteral("!")*/);
         if (attentionIconName.isNull() && attentionIcon.isNull()) {
             // code adapted from kmail's KMSystemTray::updateCount()
             int overlaySize = 22;
@@ -1033,10 +1035,10 @@ void KStatusNotifierItemPrivate::syncLegacySystemTrayIcon()
             p.setFont(labelFont);
             p.setBrush(Qt::NoBrush);
             // this sort of badge/label is red on OS X
-            p.setPen(QColor(224,0,0));
+            p.setPen(QColor(224, 0, 0));
             p.setOpacity(1.0);
             // use U+2022, the Unicode bullet
-            p.drawText(overlayPixmap.rect(), Qt::AlignRight|Qt::AlignTop, QString(QChar(0x2022)));
+            p.drawText(overlayPixmap.rect(), Qt::AlignRight | Qt::AlignTop, QString(QChar(0x2022)));
             p.end();
 
             QPixmap iconPixmap = attnIcon.pixmap(overlaySize, overlaySize);
@@ -1062,9 +1064,9 @@ void KStatusNotifierItemPrivate::syncLegacySystemTrayIcon()
 #ifdef Q_OS_MACOS
         if (!iconName.isNull()) {
             QIcon theIcon = QIcon::fromTheme(iconName);
-            systemTrayIcon->setIconWithMask(theIcon, status==KStatusNotifierItem::Passive);
+            systemTrayIcon->setIconWithMask(theIcon, status == KStatusNotifierItem::Passive);
         } else {
-            systemTrayIcon->setIconWithMask(icon, status==KStatusNotifierItem::Passive);
+            systemTrayIcon->setIconWithMask(icon, status == KStatusNotifierItem::Passive);
         }
         QtMac::setBadgeLabelText(QString());
 #else
@@ -1121,11 +1123,9 @@ void KStatusNotifierItemPrivate::maybeQuit()
 
     QString query = KStatusNotifierItem::tr("<qt>Are you sure you want to quit <b>%1</b>?</qt>").arg(caption);
 
-    if (QMessageBox::question(associatedWidget,
-                              KStatusNotifierItem::tr("Confirm Quit From System Tray", "@title:window"), query) == QMessageBox::Yes) {
+    if (QMessageBox::question(associatedWidget, KStatusNotifierItem::tr("Confirm Quit From System Tray", "@title:window"), query) == QMessageBox::Yes) {
         qApp->quit();
     }
-
 }
 
 void KStatusNotifierItemPrivate::minimizeRestore()
@@ -1152,6 +1152,9 @@ void KStatusNotifierItemPrivate::minimizeRestore(bool show)
         associatedWidget->setWindowState(state);
         associatedWidget->show();
         associatedWidget->raise();
+        if (associatedWidget->window()) {
+            KWindowSystem::activateWindow(associatedWidget->window()->winId());
+        }
     } else {
         onAllDesktops = info.onAllDesktops();
         associatedWidget->hide();
@@ -1171,9 +1174,9 @@ KDbusImageStruct KStatusNotifierItemPrivate::imageToStruct(const QImage &image)
         icon.data = QByteArray((char *)image32.bits(), image32.sizeInBytes());
     }
 
-    //swap to network byte order if we are little endian
+    // swap to network byte order if we are little endian
     if (QSysInfo::ByteOrder == QSysInfo::LittleEndian) {
-        quint32 *uintBuf = (quint32 *) icon.data.data();
+        quint32 *uintBuf = (quint32 *)icon.data.data();
         for (uint i = 0; i < icon.data.size() / sizeof(quint32); ++i) {
             *uintBuf = qToBigEndian(*uintBuf);
             ++uintBuf;
@@ -1189,7 +1192,7 @@ KDbusImageVector KStatusNotifierItemPrivate::iconToVector(const QIcon &icon)
 
     QPixmap iconPixmap;
 
-    //if an icon exactly that size wasn't found don't add it to the vector
+    // if an icon exactly that size wasn't found don't add it to the vector
     const auto lstSizes = icon.availableSizes();
     for (QSize size : lstSizes) {
         iconPixmap = icon.pixmap(size);
